import 'package:flutter/material.dart';
import 'package:flutter_timeline_interface/flutter_timeline_interface.dart';
import 'package:flutter_timeline_view/flutter_timeline_view.dart';

class CategorySelectorButton extends StatelessWidget {
  const CategorySelectorButton({
    required this.category,
    required this.selected,
    required this.onTap,
    required this.options,
    required this.isOnTop,
    super.key,
  });

  final TimelineCategory category;
  final bool selected;
  final void Function() onTap;
  final TimelineOptions options;
  final bool isOnTop;

  @override
  Widget build(BuildContext context) {
    var theme = Theme.of(context);

    return SizedBox(
      height: isOnTop ? 140 : 40,
      child: TextButton(
        onPressed: onTap,
        style: ButtonStyle(
          tapTargetSize: MaterialTapTargetSize.shrinkWrap,
          padding: const MaterialStatePropertyAll(
            EdgeInsets.symmetric(
              vertical: 5,
              horizontal: 12,
            ),
          ),
          fixedSize: MaterialStatePropertyAll(Size(140, isOnTop ? 140 : 20)),
          backgroundColor: MaterialStatePropertyAll(
            selected ? const Color(0xff71C6D1) : Colors.transparent,
          ),
          shape: const MaterialStatePropertyAll(
            RoundedRectangleBorder(
              borderRadius: BorderRadius.all(
                Radius.circular(8),
              ),
              side: BorderSide(
                color: Color(0xff71C6D1),
                width: 2,
              ),
            ),
          ),
        ),
        child: isOnTop
            ? SizedBox(
                width: MediaQuery.of(context).size.width,
                child: Column(
                  mainAxisAlignment: MainAxisAlignment.end,
                  crossAxisAlignment: CrossAxisAlignment.start,
                  children: [
                    Text(
                      category.title,
                      style: (options.theme.textStyles.categoryTitleStyle ??
                              theme.textTheme.labelLarge)
                          ?.copyWith(
                        color: selected
                            ? theme.colorScheme.onPrimary
                            : theme.colorScheme.onSurface,
                      ),
                      textAlign: TextAlign.start,
                    ),
                  ],
                ),
              )
            : Row(
                children: [
                  Flexible(
                    child: Text(
                      category.title,
                      style: (options.theme.textStyles.categoryTitleStyle ??
                              theme.textTheme.labelLarge)
                          ?.copyWith(
                        color: selected
                            ? theme.colorScheme.onPrimary
                            : theme.colorScheme.onSurface,
                      ),
                      textAlign: TextAlign.start,
                      overflow: TextOverflow.ellipsis,
                    ),
                  ),
                ],
              ),
      ),
    );
  }
}
